import { ICheck, IConfig, IEnv, ISidiMode, IStep } from '../models/SidiModel';
import { WorkflowConfig } from './WorkflowConfig';
import { GluegunToolbox } from 'gluegun';
export declare const sidiConfigUnwantedKeys: string[];
export declare class SidiConfig {
    version: string;
    projectType: 'ios' | 'android' | 'react-native';
    appOrLib: 'app' | 'library';
    cicd: 'bitrise' | 'codemagic';
    hasVersionedBranches: 'true' | 'false';
    updateGitStatus: 'true' | 'false';
    iosExecutableType: 'xcworkspace' | 'xcodeproj';
    sidiMode: ISidiMode;
    meta: any;
    appEnvs?: IEnv[];
    mainStepsBitrise: IStep;
    mainStepsCodemagic: Array<IStep>;
    secretFileEnvs: IEnv[];
    _workflowConfigs: {
        [key: string]: WorkflowConfig;
    };
    constructor(sidiConfig?: SidiConfig);
    /**
      Set the machine to use on cicd side
    */
    setStackToUse(meta: any): void;
    /**
      To change used cicd
    */
    changeCICD(cicd: 'bitrise' | 'codemagic'): void;
    /**
      Add a new workflow, instantiated with the name only or with a existing config from sidiConfig.json
     */
    addNewWorkflow(workflowConfig: WorkflowConfig): void;
    /**
      Delete a workflow
  
      @param workflowName: workflow's name
     */
    deleteWorkflow(workflowName: string): void;
    /**
      Update the mode - default init
  
      @param mode: sidi's mode, to know which process to launch in PrepareSteps
     */
    changeSidiMode(mode: ISidiMode): void;
    /**
      Delete a workflow
     */
    updateWorkflow(toolbox: GluegunToolbox, workflowName: string): Promise<void>;
    /**
      Set workflow's steps based on mandatorySteps or (selected) purposedSteps contents
     - check if the step has any condition
       - if yes ask input to user (only if the condition object contain "choices" object)
       - if condition false -> not added to the workflows
  
      @param toolbox: GluegunToolbox
      @param workflowName: workflow's name where it will add steps
      @param configFile: config file of the step
      @param isMandatoryStep: to know if it part of mandatory steps (mandatorySteps folder), to add steps at the top
     */
    setWorkflowSteps(toolbox: GluegunToolbox, workflowName: string, configFile: IConfig): Promise<void>;
    /**
      Ask to user if he wants to add any custom step to workflow
  
      @param toolbox: GluegunToolbox
      @param workflowName: workflow's name where it will add steps
     */
    requestCustomSteps(toolbox: GluegunToolbox, workflowName: string): Promise<void>;
    /**
      Ask to user if he wants to add any custom step to workflow's publishing step (codemagic only)
  
      @param toolbox: GluegunToolbox
      @param workflowName: workflow's name where it will add steps
     */
    requestPublishingCustomSteps(toolbox: GluegunToolbox, workflowName: string): Promise<void>;
    /**
      Ask to user if he wants to add any custom step to workflow
  
      @param workflowName: workflow's name where it will add steps
      @param stack: stack (machine) to use for this workflow
     */
    setWorkflowStack(workflowName: string, stack: any): void;
    /**
      Inject custom steps into stepsNames in the correct place
  
      @param toolbox: GluegunToolbox
      @param workflowName: workflow's name where it will add steps
     */
    setCustomSteps(toolbox: GluegunToolbox, workflowName: string): void;
    /**
     Will check if files properly set to use specific step
     Code used if we have any `checks` in config file
    */
    requiredStepChecks(workflowName: string, checks: ICheck[], toolbox: GluegunToolbox): Promise<void>;
    /**
      Will add all mandatory steps to the workflow (mandatorySteps folder)
  
      @param toolbox: GluegunToolbox
      @param workflowName: workflow's name where it will add steps
    */
    setMandatorySteps(toolbox: GluegunToolbox, workflowName: string): Promise<void>;
    /**
      Will add all dependence steps based on purposedSteps choose for each workflow
    */
    setGlobalSteps(): void;
    setStepsYAML(stepName: string, stepFile: any): void;
    addAppEnv(key: string, value: string): void;
    setEnvsForSecretFile(): void;
}
